# 2022-09-16 - Batch Relayer V4

> ⚠️ **DEPRECATED: do not use** ⚠️
> This deployment has been deprecated in favor of a new version with full support for stable pools and new protocols.
> The new version is: [batch-relayer-v5](../../20230314-batch-relayer-v5/).

Deployment of the fourth `BalancerRelayer` using `BatchRelayerLibrary`, for combining multiple operations (swaps, joins, etc.) in a single transaction.

This new version provides quality of life improvements, like read-only chained references and ways to read them.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Polygon mainnet addresses](./output/polygon.json)
- [Arbitrum mainnet addresses](./output/arbitrum.json)
- [Optimism mainnet addresses](./output/optimism.json)
- [BSC mainnet addresses](./output/bsc.json)
- [Gnosis mainnet addresses](./output/gnosis.json)
- [Avalanche mainnet addresses](./output/avalanche.json)
- [Goerli testnet addresses](./output/goerli.json)
- [`BatchRelayerLibrary` artifact](./artifact/BatchRelayerLibrary.json)
